<?php
/**
 * @file
 * KerberosInterface class definition.
 */
/**
 * KerberosInterface Class
 */
class KerberosInterface {
  const KRB5_CONF = '/etc/krb5.conf';
  private $realm; //Realm Name
  private $credential_cache;

  /**
   * @param $realm_name string Realm to use in this KerberosInterface
   */
  public function __construct($realm_name) {
    $this->realm = $realm_name;
  }

  /**
   * Set realm for this KerberosInterface
   *
   * @param $realm string Realm to use
   */
  public function setRealm($realm) {
    $this->realm = $realm;
  }

  /**
   * Get realm that this KerberosInterface uses
   * @return string Realm that this KerberosInterface uses
   */
  public function getRealm() {
    return $this->realm;
  }

  /**
   * Get all Kerberos tickets for a principle/password combination
   *
   * @param  $principle string Principle for which to get tickets
   * @param  $password  string Password to use to authenticate the principle
   *
   * @return array tickets for the principle

   */
  public function getTickets($principle, $password) {
    $this->credential_cache = new KRB5CCache();
    $this->credential_cache->setConfig(self::KRB5_CONF); //default config for kerberos
    if ( strpos('@', $principle) === FALSE ) { //Add realm if it's not already part of principle
      $principle = $principle . '@' . $this->realm;
    }
    $this->credential_cache->initPassword($principle, $password);
    $entries = $this->credential_cache->getEntries(); //returns the same as running `klist`
    return $entries;
  }

  /**
   * Check if a principle/password combination is valid
   *
   * @param  $principle string Principle for which to get tickets
   * @param  $password  string Password to use to authenticate the principle
   *
   * @return boolean TRUE if valid principle, FALSE on failure
   */
  public function checkPrinciple($principle, $password) {
    $tickets = $this->getTickets($principle, $password);
    if ( !empty( $tickets ) ) {
      return TRUE;
    }
    return FALSE;
  }

}